.. _sound-label:

Sound Processing Utilities
==========================

This module contains two classes:

Classes
-------
.. autosummary::

    sounds.Sound
    sounds.FFMPEG_info


Methods Sound
^^^^^^^^^^^^^
.. autosummary::

    sounds.Sound.generate_sound
    sounds.Sound.get_info
    sounds.Sound.play
    sounds.Sound.read_sound
    sounds.Sound.summary
    sounds.Sound.write_wav

.. toctree::
   :maxdepth: 2

Methods FFMPEG_info
^^^^^^^^^^^^^^^^^^^
.. autosummary::

    sounds.FFMPEG_info.set

.. toctree::
   :maxdepth: 2

Details
-------
.. automodule:: sounds
    :members:

